[Lldb-commits] [lldb] r189073 - Update ABISysV_x86_64::CallFrameAddressIsValid() to check for
Jason Molenda
jmolenda at apple.com
Thu Aug 22 15:51:48 PDT 2013
Author: jmolenda
Date: Thu Aug 22 17:51:48 2013
New Revision: 189073
URL: http://llvm.org/viewvc/llvm-project?rev=189073&view=rev
Log:
Update ABISysV_x86_64::CallFrameAddressIsValid() to check for
16-byte alignment of stack frames.
Modified:
lldb/trunk/source/Plugins/ABI/SysV-x86_64/ABISysV_x86_64.h
Modified: lldb/trunk/source/Plugins/ABI/SysV-x86_64/ABISysV_x86_64.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/ABI/SysV-x86_64/ABISysV_x86_64.h?rev=189073&r1=189072&r2=189073&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/ABI/SysV-x86_64/ABISysV_x86_64.h (original)
+++ lldb/trunk/source/Plugins/ABI/SysV-x86_64/ABISysV_x86_64.h Thu Aug 22 17:51:48 2013
@@ -76,9 +76,9 @@ public:
virtual bool
CallFrameAddressIsValid (lldb::addr_t cfa)
{
- // Make sure the stack call frame addresses are are 8 byte aligned
- if (cfa & (8ull - 1ull))
- return false; // Not 8 byte aligned
+ // Make sure the stack call frame addresses are 16 byte aligned
+ if (cfa & (16ull - 1ull))
+ return false; // Not 16 byte aligned
if (cfa == 0)
return false; // Zero is not a valid stack address
return true;
More information about the lldb-commits
mailing list